@@ -12,9 +12,14 @@ def after_copy():
     """Steps to run after the templates has been copied in place."""
     # 1. Import red-boilerplate in place using git
     os.system("git init")
+    os.system("git add .")
+    os.system("git commit -a -m'Django project created with django-start'")
     os.system("git remote add -f boilerplate git://github.com/ff0000/red-boilerplate.git")
     os.system("git pull boilerplate master")
-    os.system("git commit -m'Started new project from red-boilerplate'")
+    os.system("git pull boilerplate master")
+    os.system("git rm README.md")
+    os.system("git mv INSTRUCTIONS.md README.md")
+    os.system("git commit -m'Pulled files from red-boilerplate'")
 
     # 2. Replace boilerplate variables with prompt values or defaults
     placemarks = [
